XDG-compliant theme loader for Terminal Colors Architecture.
Provides filesystem operations for discovering and loading TCA themes from XDG data directories.
Functions
- find_
theme - Find a theme by name (with or without
.tomlextension). - get_
data_ dir - Get the TCA data directory path, creating it if it does not exist.
- get_
themes_ dir - Get the themes directory path, creating it if it does not exist.
- list_
theme_ names - List all theme names (without paths or extensions).
- list_
themes - List all available theme files in the shared themes directory.
- load_
all_ from_ dir - Load all themes from a given directory as raw
tca_types::Themevalues. - load_
all_ from_ theme_ dir - Load all locally installed themes from the shared theme directory.
- load_
theme_ file - Load a theme file from one of these locations (searched in order):