load_all_from_dir

Function load_all_from_dir 

pub fn load_all_from_dir(dir: &str) -> Result<Vec<Theme>>
Load all themes from a given directory as raw tca_types::Theme values.

Entries that cannot be read or parsed are skipped with a message to stderr.